# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2024-11-22 11:57:18
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class UserDataModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None):
        super(UserDataModel, self).__init__(UserData, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(db_config_dict)
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class UserData:
    def __init__(self):
        super(UserData, self).__init__()
        self.id = 0 # id
        self.user_id = "" # 客户ID
        self.ouid = "" # ouid
        self.business_id = 0 # 商家标识
        self.store_id = 0 # 店铺标识
        self.plat_store_id = "" # 平台店铺标识
        self.first_order_date = "1970-01-01 00:00:00.000" # 首次下单时间
        self.first_pay_date = "1970-01-01 00:00:00.000" # 首次付款时间
        self.last_order_date = "1970-01-01 00:00:00.000" # 最近下单时间
        self.last_pay_date = "1970-01-01 00:00:00.000" # 最近付款时间
        self.last_trade_date = "1970-01-01 00:00:00.000" # 最近交易时间
        self.trade_success_price = 0.0000 # 交易成功金额
        self.trade_success_num = 0 # 交易成功笔数
        self.refund_price = 0.0000 # 退款金额
        self.refund_num = 0 # 退款笔数
        self.presell_order_num = 0 # 预售下单笔数
        self.presell_pay_num = 0 # 预售付款笔数
        self.presell_order_price = 0.0000 # 预售下单金额
        self.presell_pay_price = 0.0000 # 预售付款金额
        self.buy_back_day = 0 # 回购周期天

    @classmethod
    def get_field_list(cls):
        return [
            'id', 'user_id', 'ouid', 'business_id', 'store_id', 'plat_store_id', 'first_order_date',
            'first_pay_date', 'last_order_date', 'last_pay_date', 'last_trade_date',
            'trade_success_price', 'trade_success_num', 'refund_price', 'refund_num',
            'presell_order_num', 'presell_pay_num', 'presell_order_price',
            'presell_pay_price', 'buy_back_day'
        ]

    @classmethod
    def get_primary_key(cls):
        return "id"

    def __str__(self):
        return "user_data_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-18 18:57:33
@LastEditTime: 2024-11-28 11:39:32
@LastEditors: HuangJianYi
@Description: 
"""
from datetime import datetime, timedelta
import math
from copy import deepcopy
from seven_cloudapp_frame.libs.customize.seven_helper import *
from hk_cdp.models.enum import *

class CdpHelper:
    
    @classmethod
    def get_business_db(self, business_code, cdp_db_config):
        """
        :description: 获取对应的数据库名
        :param business_code: 商家代码
        :param cdp_db_config: 数据库连接串
        :last_editors: HuangJianYi
        """
        cdp_db_config = SevenHelper.json_loads(cdp_db_config)
        rawdata_db_config = cdp_db_config
        rawdata_db_config['db'] = f"hk_{business_code}_rawdata"
        cdp_db_config = deepcopy(cdp_db_config)
        cdp_db_config["db"] = f"hk_{business_code}_cdp"
        return rawdata_db_config, cdp_db_config 
    
    @classmethod
    def get_valid_date(self, valid_type, expire_type, expire_value, expire_year, expire_month, expire_day):
        """
        :description: 计算积分/成长值过期时间
        :param valid_type: 有效类型(1-永久有效 2-指定时间)
        :param expire_type: 过期类型(1-指定天 2-指定时间)
        :param expire_value: 过期值
        :param expire_year: 过期年
        :param expire_month: 过期月
        :param expire_day: 过期日
        :last_editors: HuangJianYi
        """
        if valid_type == ValidType.forever.value:
            return '2900-01-01 00:00:00'
        else:
            if expire_type == ExpireType.appoint_day.value: # 指定天过期
                return (datetime.now() + timedelta(days=int(expire_value))).strftime("%Y-%m-%d 23:59:59")
            else:
                if expire_year and expire_month and expire_day:
                    current_year = datetime.now().year
                    expire_date = datetime(current_year + int(expire_year), int(expire_month), int(expire_day), 23, 59, 59)
                    return expire_date.strftime("%Y-%m-%d 23:59:59")
                else:
                    return '2900-01-01 00:00:00'

    @classmethod
    def reward_algorithm(self, value_type, reward_value):
        """
        :description: 奖励算法
        :param value_type: 算法类型(1-四舍五入 2-向上取整 3-向下取整)
        :param reward_value: 根据订单算法的值
        :last_editors: HuangJianYi
        """
        if value_type == RoundingType.half_up.value: # 四舍五入
            reward_value = round(reward_value)
        elif value_type == RoundingType.ceiling.value: # 向上取整
            reward_value = math.ceil(reward_value)
        elif value_type == RoundingType.floor.value: # 向下取整
            reward_value = math.floor(reward_value)
        return reward_value



   


#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class TaoBaoRdsItemModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(TaoBaoRdsItemModel, self).__init__(TaoBaoRdsItem, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类


class TaoBaoRdsItem:
    def __init__(self):
        super(TaoBaoRdsItem, self).__init__()
        self.num_iid = 0  # 商品号
        self.seller_nick = ""  # 卖家昵称
        self.approve_status = ""  # 类型
        self.has_showcase = ""  # 卖家昵称
        self.created = ""  # 创建时间
        self.modified = ""  # 修改时间
        self.cid = ""  # 分类id
        self.has_discount = ""  # 分类id
        self.jdp_hashcode = ""  # jdp_hashcode
        self.jdp_response = ""  # 接口返回值
        self.jdp_delete = 0  # jdp_delete
        self.jdp_created = ""  # jdp_created
        self.jdp_modified = ""  # jdp_modified

    @classmethod
    def get_field_list(self):
        return ['num_iid', 'seller_nick', 'approve_status', 'has_showcase', 'created', 'modified', 'cid', 'has_discount', 'jdp_hashcode', 'jdp_response', 'jdp_delete', 'jdp_created', 'jdp_modified']

    @classmethod
    def get_primary_key(self):
        return "num_iid"

    def __str__(self):
        return "taobao_rds_item_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-06 09:39:45
@LastEditTime: 2024-11-26 17:42:25
@LastEditors: HuangJianYi
@Description: 
"""

# 此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class StoreInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_hk_cap', sub_table=None, db_transaction=None, context=None):
        super(StoreInfoModel, self).__init__(StoreInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class StoreInfo:

    def __init__(self):
        super(StoreInfo, self).__init__()
        self.id = 0  # id
        self.guid = None  # guid
        self.business_id = 0  # 商家标识
        self.platform_id = 0  # 平台类型
        self.store_name = ""  # 店铺名称
        self.seller_nick = ""  # 店铺主账号
        self.store_icon = ""  # 店铺图标
        self.plat_store_id = ""  # 平台店铺标识
        self.store_status = 0  # 店铺状态
        self.plat_telephone_key = ""  # 平台手机号密钥
        self.prefix_status = 0  # 号段生成状态
        self.prefix_path = ""  # 号段存储路径
        self.overdue_date = '1970-01-01 00:00:00.000'  # 过期时间
        self.access_token = ""  # access_token
        self.description = ""  # 描述
        self.cdp_rawdata_sync_status = 0  # cdp_原始数据同步状态
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间
        self.modify_date = '1970-01-01 00:00:00.000'  # 修改时间

    @classmethod
    def get_field_list(cls):
        return [
            'id', 'guid', 'business_id', 'platform_id', 'store_name', 
            'seller_nick', 'store_icon', 'plat_store_id', 'store_status', 
            'plat_telephone_key', 'prefix_status', 'prefix_path', 
            'overdue_date', 'access_token', 'description', 
            'cdp_rawdata_sync_status', 'create_date', 'modify_date'
        ]
        
    @classmethod
    def get_primary_key(cls):
        return "id"

    def __str__(self):
        return "store_info_tb"




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class BusinessInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_hk_cap', sub_table=None, db_transaction=None, context=None):
        super(BusinessInfoModel, self).__init__(BusinessInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class BusinessInfo:

    def __init__(self):
        super(BusinessInfo, self).__init__()
        self.id = 0  # id
        self.guid = None  # guid
        self.business_name = ""  # 商家名称
        self.is_release = 0  # 是否发布(1-是 0-否)
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间
        self.business_code = ""  # 商家代码
        self.cdp_db_config = None  # cdp商家连接串

    @classmethod
    def get_field_list(self):
        return ['id', 'guid', 'business_name', 'is_release', 'create_date', 'modify_date', 'business_code', 'cdp_db_config']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "business_info_tb"
    


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2024-11-14 15:17:37
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class SchemeLevelModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None):
        super(SchemeLevelModel, self).__init__(SchemeLevel, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(db_config_dict)
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class SchemeLevel:
    def __init__(self):
        super(SchemeLevel, self).__init__()
        self.id = 0
        self.guid = "" # guid
        self.scheme_id = 0 # 会员体系标识
        self.is_unify_valid = 0 # 是否统一有效期(1-是 0-差异化)  
        self.valid_type = 0 # 有效期类型(1-永久有效 2-过期时间） 
        self.expire_type = 0 # 过期类型（1-指定天 2-指定具体时间）
        self.expire_select_type = 0 # 过期选项类型(0-当年 1-1年 2-2年)
        self.expire_value = '' # 过期值
        self.is_demote = 0 # 是否开启会员降级(1-是 0-否）
        self.demote_type = 0 # 降级类型（1-降1级 2-按升级规则 3-按保级规则）
        self.create_date = '1970-01-01 00:00:00.000' # 创建时间
        self.modify_date = '1970-01-01 00:00:00.000' # 修改时间

    @classmethod
    def get_field_list(cls):
        return [
            'id', 'guid', 'scheme_id', 'is_unify_valid', 'valid_type', 'expire_type', 'expire_select_type', 'expire_value', 'is_demote', 'demote_type', 'create_date', 'modify_date'
        ]

    @classmethod
    def get_primary_key(cls):
        return "id"

    def __str__(self):
        return "scheme_level_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-22 17:23:58
@LastEditTime: 2024-11-22 17:25:30
@LastEditors: HuangJianYi
@Description: 
"""
__all__ = ["store_base_model","store_info_model"]
